summaryrefslogtreecommitdiff
path: root/vcl/coretext/ctlayout.cxx
diff options
context:
space:
mode:
authorKhaled Hosny <khaledhosny@eglug.org>2013-06-02 12:43:36 +0200
committerKhaled Hosny <khaledhosny@eglug.org>2013-06-03 15:11:54 +0200
commitee9fd88741202a95b47886116815b04f643459d4 (patch)
treeeba42ac287ecafe41f6007b6c5891a2765e48dbc /vcl/coretext/ctlayout.cxx
parentea8422d42e838e7ddfeb8d9f77f3ecedecb29ce8 (diff)
Get the new Core Text code to compile
Change-Id: I592158bd60afcbe756c6f0e11aa69a44768a0985
Diffstat (limited to 'vcl/coretext/ctlayout.cxx')
-rw-r--r--vcl/coretext/ctlayout.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/vcl/coretext/ctlayout.cxx b/vcl/coretext/ctlayout.cxx
index d232910a41c3..30da812c88fc 100644
--- a/vcl/coretext/ctlayout.cxx
+++ b/vcl/coretext/ctlayout.cxx
@@ -47,7 +47,7 @@ public:
virtual bool GetGlyphOutlines( SalGraphics&, PolyPolyVector& ) const;
virtual bool GetBoundRect( SalGraphics&, Rectangle& ) const;
- const ImplFontData* GetFallbackFontData( sal_GlyphId ) const;
+ const PhysicalFontFace* GetFallbackFontData( sal_GlyphId ) const;
virtual void InitFont( void) const;
virtual void MoveGlyph( int nStart, long nNewXPos );
@@ -396,7 +396,7 @@ long CTLayout::FillDXArray( sal_Int32* pDXArray ) const
// -----------------------------------------------------------------------
-int CTLayout::GetTextBreak( long nMaxWidth, long nCharExtra, int nFactor ) const
+int CTLayout::GetTextBreak( long nMaxWidth, long /*nCharExtra*/, int nFactor ) const
{
if( !mpCTLine )
return STRING_LEN;
@@ -469,9 +469,9 @@ void CTLayout::MoveGlyph( int /*nStart*/, long /*nNewXPos*/ ) {}
void CTLayout::DropGlyph( int /*nStart*/ ) {}
void CTLayout::Simplify( bool /*bIsBase*/ ) {}
// get the ImplFontData for a glyph fallback font
// for a glyphid that was returned by CTLayout::GetNextGlyphs()
-const ImplFontData* CTLayout::GetFallbackFontData( sal_GlyphId /*nGlyphId*/ ) const
+const PhysicalFontFace* CTLayout::GetFallbackFontData( sal_GlyphId /*nGlyphId*/ ) const
{
#if 0
// check if any fallback fonts were needed
@@ -484,7 +484,7 @@ const ImplFontData* CTLayout::GetFallbackFontData( sal_GlyphId /*nGlyphId*/ ) co
pFallbackFont = mpFallbackInfo->GetFallbackFontData( nFallbackLevel );
#else
// let CoreText's font cascading handle glyph fallback
- const ImplFontData* pFallbackFont = NULL;
+ const PhysicalFontFace* pFallbackFont = NULL;
#endif
return pFallbackFont;
}
@@ -469,9 +469,9 @@ void CTLayout::MoveGlyph( int /*nStart*/, long /*nNewXPos*/ ) {}
void CTLayout::DropGlyph( int /*nStart*/ ) {}
void CTLayout::Simplify( bool /*bIsBase*/ ) {}
-// get the ImplFontData for a glyph fallback font
+// get the PhysicalFontFace for a glyph fallback font
// for a glyphid that was returned by CTLayout::GetNextGlyphs()